==> cdk-lambda-subminute-2.0.148-sources.jar: io/github/hsiehshujeng/cdk/lambda/subminute/LambdaSubminute.java <==
package io.github.hsiehshujeng.cdk.lambda.subminute;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.80.0 (build bce6a1d)", date = "2023-05-10T01:14:30.144Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = io.github.hsiehshujeng.cdk.lambda.subminute.$Module.class, fqn = "cdk-lambda-subminute.LambdaSubminute")
public class LambdaSubminute extends software.constructs.Construct {

    protected LambdaSubminute(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaSubminute(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param parent This parameter is required.
     * @param name This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public LambdaSubminute(final @org.jetbrains.annotations.NotNull software.constructs.Construct parent, final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.NotNull io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminuteProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(parent, "parent is required"), java.util.Objects.requireNonNull(name, "name is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * The Lambda function that plays the role of the iterator.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction getIteratorFunction() {
        return software.amazon.jsii.Kernel.get(this, "iteratorFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.IFunction.class));
    }

    /**
     * The ARN of the state machine that executes the target Lambda function per time unit less than one minute.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getStateMachineArn() {
        return software.amazon.jsii.Kernel.get(this, "stateMachineArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A fluent builder for {@link io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminute}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminute> {
        /**
         * @return a new instance of {@link Builder}.
         * @param parent This parameter is required.
         * @param name This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct parent, final java.lang.String name) {
            return new Builder(parent, name);
        }

        private final software.constructs.Construct parent;
        private final java.lang.String name;
        private final io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminuteProps.Builder props;

        private Builder(final software.constructs.Construct parent, final java.lang.String name) {
            this.parent = parent;
            this.name = name;
            this.props = new io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminuteProps.Builder();
        }

        /**
         * The Lambda function that is going to be executed per time unit less than one minute.
         * <p>
         * @return {@code this}
         * @param targetFunction The Lambda function that is going to be executed per time unit less than one minute. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetFunction(final software.amazon.awscdk.services.lambda.IFunction targetFunction) {
            this.props.targetFunction(targetFunction);
            return this;
        }

        /**
         * A pattern you want this statemachine to be executed.
         * <p>
         * Default: cron(50/1 15-17 ? * * *) UTC+0 being run every minute starting from 15:00 PM to 17:00 PM.
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/events/ScheduledEvents.html">https://docs.aws.amazon.com/AmazonCloudWatch/latest/events/ScheduledEvents.html</a>
         * @param cronjobExpression A pattern you want this statemachine to be executed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cronjobExpression(final java.lang.String cronjobExpression) {
            this.props.cronjobExpression(cronjobExpression);
            return this;
        }

        /**
         * How many times you intent to execute in a minute.
         * <p>
         * Default: 6
         * <p>
         * @return {@code this}
         * @param frequency How many times you intent to execute in a minute. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder frequency(final java.lang.Number frequency) {
            this.props.frequency(frequency);
            return this;
        }

        /**
         * Seconds for an interval, the product of `frequency` and `intervalTime` should be approximagely 1 minute.
         * <p>
         * Default: 10
         * <p>
         * @return {@code this}
         * @param intervalTime Seconds for an interval, the product of `frequency` and `intervalTime` should be approximagely 1 minute. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder intervalTime(final java.lang.Number intervalTime) {
            this.props.intervalTime(intervalTime);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminute}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminute build() {
            return new io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminute(
                this.parent,
                this.name,
                this.props.build()
            );
        }
    }
}

==> cdk-lambda-subminute-2.0.417-sources.jar: io/github/hsiehshujeng/cdk/lambda/subminute/LambdaSubminute.java <==
package io.github.hsiehshujeng.cdk.lambda.subminute;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-03-30T01:02:55.410Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = io.github.hsiehshujeng.cdk.lambda.subminute.$Module.class, fqn = "cdk-lambda-subminute.LambdaSubminute")
public class LambdaSubminute extends software.constructs.Construct {

    protected LambdaSubminute(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaSubminute(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param parent This parameter is required.
     * @param name This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public LambdaSubminute(final @org.jetbrains.annotations.NotNull software.constructs.Construct parent, final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.NotNull io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminuteProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(parent, "parent is required"), java.util.Objects.requireNonNull(name, "name is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * The Lambda function that plays the role of the iterator.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunction getIteratorFunction() {
        return software.amazon.jsii.Kernel.get(this, "iteratorFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.IFunction.class));
    }

    /**
     * The ARN of the state machine that executes the target Lambda function per time unit less than one minute.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getStateMachineArn() {
        return software.amazon.jsii.Kernel.get(this, "stateMachineArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A fluent builder for {@link io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminute}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminute> {
        /**
         * @return a new instance of {@link Builder}.
         * @param parent This parameter is required.
         * @param name This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct parent, final java.lang.String name) {
            return new Builder(parent, name);
        }

        private final software.constructs.Construct parent;
        private final java.lang.String name;
        private final io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminuteProps.Builder props;

        private Builder(final software.constructs.Construct parent, final java.lang.String name) {
            this.parent = parent;
            this.name = name;
            this.props = new io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminuteProps.Builder();
        }

        /**
         * The Lambda function that is going to be executed per time unit less than one minute.
         * <p>
         * @return {@code this}
         * @param targetFunction The Lambda function that is going to be executed per time unit less than one minute. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetFunction(final software.amazon.awscdk.services.lambda.IFunction targetFunction) {
            this.props.targetFunction(targetFunction);
            return this;
        }

        /**
         * A pattern you want this statemachine to be executed.
         * <p>
         * Default: cron(50/1 15-17 ? * * *) UTC+0 being run every minute starting from 15:00 PM to 17:00 PM.
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/AmazonCloudWatch/latest/events/ScheduledEvents.html">https://docs.aws.amazon.com/AmazonCloudWatch/latest/events/ScheduledEvents.html</a>
         * @param cronjobExpression A pattern you want this statemachine to be executed. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cronjobExpression(final java.lang.String cronjobExpression) {
            this.props.cronjobExpression(cronjobExpression);
            return this;
        }

        /**
         * How many times you intent to execute in a minute.
         * <p>
         * Default: 6
         * <p>
         * @return {@code this}
         * @param frequency How many times you intent to execute in a minute. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder frequency(final java.lang.Number frequency) {
            this.props.frequency(frequency);
            return this;
        }

        /**
         * Seconds for an interval, the product of <code>frequency</code> and <code>intervalTime</code> should be approximagely 1 minute.
         * <p>
         * Default: 10
         * <p>
         * @return {@code this}
         * @param intervalTime Seconds for an interval, the product of <code>frequency</code> and <code>intervalTime</code> should be approximagely 1 minute. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder intervalTime(final java.lang.Number intervalTime) {
            this.props.intervalTime(intervalTime);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminute}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminute build() {
            return new io.github.hsiehshujeng.cdk.lambda.subminute.LambdaSubminute(
                this.parent,
                this.name,
                this.props.build()
            );
        }
    }
}
